Skip to contents

Lists the data files available in a downloaded School Census. Use this to discover which files are available for a given year, then pass the desired file name to get_censo_escolar()'s file parameter.

Usage

list_censo_files(year)

Arguments

year

The year of the census.

Value

A character vector of file names found.

See also

Other School Census functions: get_censo_escolar()

Examples

if (FALSE) { # \dontrun{
# first download the data
get_censo_escolar(1995)

# then see what files are available
list_censo_files(1995)
# [1] "CENSOESC_1995.CSV" "DADOS_DESP_1995.CSV" "DADOSCURSO_1995.CSV"

# load a specific file
cursos <- get_censo_escolar(1995, file = "DADOSCURSO")
} # }