Sets the directory where downloaded files will be cached. This avoids repeated downloads of the same data.
See also
Other cache functions:
clear_cache(),
get_cache_dir(),
list_cache()
Sets the directory where downloaded files will be cached. This avoids repeated downloads of the same data.
Other cache functions:
clear_cache(),
get_cache_dir(),
list_cache()